/* slurp-resource.h
 *
 * Copyright © 2017 Julian Richen <julian@richen.io>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SLURP_RESOURCE_H
#define SLURP_RESOURCE_H

#include <glib-object.h>

#include <glib.h>
#include <gio/gio.h>
#include <libsoup/soup.h>

G_BEGIN_DECLS

#define SLURP_TYPE_RESOURCE (slurp_resource_get_type())

G_DECLARE_FINAL_TYPE (SlurpResource, slurp_resource, SLURP, RESOURCE, GObject)

//TODO: Offer seeking
// https://github.com/GNOME/rhythmbox/blob/7f88a0ae0eed1251328e10b92175e35c0deb645d/podcast/rb-podcast-manager.c#L1555

SlurpResource *
slurp_resource_new (void);

gboolean
slurp_resource_download (SlurpResource *self,
                         const gchar   *uri);

gboolean
slurp_resource_download_full (SlurpResource *self,
                              const gchar   *uri,
                              const gchar   *file,
                              gboolean       overwrite);

void
slurp_resource_download_async (SlurpResource *self,
                               const gchar   *uri,
                               GCancellable  *cancellable);

void
slurp_resource_download_async_full (SlurpResource       *self,
                                    const gchar         *uri,
                                    const gchar         *file,
                                    gboolean             overwrite
                                    GCancellable        *cancellable,
                                    GCallback            p_handler,
                                    gpointer             p_user_data,
                                    GAsyncReadyCallback  callback,
                                    gpointer             user_data);

gboolean
slurp_resource_download_finish (SlurpResource  *self,
                                GAsyncResult   *result,
                                GError        **error);

GOutputSteam *
slurp_resource_stream ();

GOutputSteam *
slurp_resource_download_and_stream ();

GdkPixbuf *
slurp_resource_gdkpixbuf ();

GdkPixbuf *
slurp_resource_download_and_gdkpixbuf ();

G_END_DECLS

#endif /* SLURP_RESOURCE_H */

